/*
 * Interrupt_test.c
 *
 *  Created on: Jun 28, 2011
 *      Author: GSI
 */

#include <usbstk5515.h>
#include <usbstk5515_interrupts.h>
#include <stdio.h>
#define LED_OUT1 *((ioport volatile Uint16*)0x1c0a)
#define LED_OUT2 *((ioport volatile Uint16*)0x1c0b)
#define LED_DIR1 *((ioport volatile Uint16*)0x1c06)
#define LED_DIR2 *((ioport volatile Uint16*)0x1c07)


#define TINT   0x20
#define TINT_BIT 4

#define TIME_START  		0x8001
#define TIME_STOP   		0x8000
#define TIME_START_AUTOLOAD 0x8003

Uint32 program_counter = 0; // This counter is used for your own application


void Reset();

void My_LED_init()
{
	LED_DIR1 |= 0xC000;
	LED_DIR2 |= 0x0003;

	LED_OUT1 |= 0xC000;  //Set LEDs 0, 1 to off
	LED_OUT2 |= 0x0003;  //Set LEDs 2, 3 to off
}

interrupt void Timer_Handler()
{
	program_counter++;
	TIAFR = 0x0001;

}

Uint16 time_set;
Uint32 reset_loc = (Uint32)Reset;

void Timer_setup()
{
	//Set up Interrupt Vector Pointer Table
	IVPD = reset_loc >> 8;
	IVPH = reset_loc >> 8;

	*((Uint32*)((reset_loc + TINT)>>1)) = (Uint32)Timer_Handler; //Table points to our handler

	IER0 |= (1 << TINT_BIT);//enable interrupt
	IFR0 &= (1 << TINT_BIT);//clear the flag

	TCR0 = TIME_STOP;
	TPR0_1  = 199;
	//Set the other period reg and both counters to 0
	TPR0_2 = TCR0_1 = TCR0_2 = 0;

	TIAFR = 0x0007; // Set the flag

	TCR0 |= TIME_START_AUTOLOAD;
}

void main(void)
{
//	Uint16 change = 0xFFFF;
	USBSTK5515_init();
	My_LED_init();
	Timer_setup();
	_enable_interrupts();

	if(IER0 == 0)
	{
		printf("erb?, no enabled interrupts\n");
		goto TERMINATE;
	}

	while(1)
	{
		if(program_counter >= (Uint32)50000)
		{
			program_counter = 0;
			LED_OUT1 ^= 0xC000;
			LED_OUT2 ^= 0x0003;

		}
	}
TERMINATE:
printf("TERMINATING\n");

}

